@@ -6,7 +6,7 @@ use English qw[-no_match_vars];
 use Moo;
 use App::Table2YAML;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 has opts    => ( is => q(rw), default => sub { {}; }, );
 has errors  => ( is => q(rw), default => sub { []; }, );
@@ -24,7 +24,9 @@ sub _get_loaders {
     my $self = shift;
 
     use App::Table2YAML::Loader;
-    my $obj        = App::Table2YAML::Loader->new();
+    my $obj = App::Table2YAML::Loader->new();
+    $obj->field_separator(q());
+    $obj->record_separator(q());
     my @method     = $obj->meta->get_method_list();
     my $prefix_str = q(load_);
     my $prefix_len = length($prefix_str);
@@ -126,7 +128,19 @@ sub parse_opts {
     return @{ $self->errors() } ? 0 : 1;
 } ## end sub parse_opts
 
-sub _parse_opts_asciitable {...}
+sub _parse_opts_asciitable {
+    my $self = shift;
+    my %opt = splice @_;
+
+    foreach my $opt ( keys %opt ) {
+        next if $opt eq q(record_separator);
+        my $msg = qq(asciitable and '--$opt' are incompatible.\nIgnored.);
+        say $msg;
+        delete $opt{$opt};
+    }
+
+    return %opt;
+}
 
 sub _parse_opts_dsv {
     my $self = shift;
@@ -241,7 +255,7 @@ App::Table2YAML::CLI - Command Line Interface functions.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
